# Changelog

## [1.0.1a1](https://github.com/OpenVoiceOS/ovos-backend-client/tree/1.0.1a1) (2024-11-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/V1.0.0...1.0.1a1)

**Closed issues:**

- Oauth2 App database should not require the refresh\_endpoint [\#59](https://github.com/OpenVoiceOS/ovos-backend-client/issues/59)

**Merged pull requests:**

- fix:nominatim [\#82](https://github.com/OpenVoiceOS/ovos-backend-client/pull/82) ([JarbasAl](https://github.com/JarbasAl))

## [V1.0.0](https://github.com/OpenVoiceOS/ovos-backend-client/tree/V1.0.0) (2024-09-11)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-backend-client/compare/1.0.0...V1.0.0)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
